==> ehcache-core-2.0.0-sources.jar: net/sf/ehcache/transaction/manager/TransactionManagerLookup.java <==
/**
 *  Copyright 2003-2009 Terracotta, Inc.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package net.sf.ehcache.transaction.manager;

import javax.transaction.TransactionManager;

import net.sf.ehcache.transaction.xa.EhcacheXAResource;

import java.util.Properties;

/**
 * Interface to enable a XA transactional cache to access the JTA TransactionManager.
 * The implementing class can be configured in your xml file. It will then be instanciated by the Cache, during
 * {@link net.sf.ehcache.Cache#initialise() initialization}. It'll then have the properties injected, should any have been specified. And finally,
 * the TransactionManager will be queried for using #getTransactionManager.
 *
 * @author Alex Snaps
 */
public interface TransactionManagerLookup {

    /**
     * Lookup available txnManagers
     * @return TransactionManager
     */
    TransactionManager getTransactionManager();

    /**
     * execute txnManager specific code.
     */
    void register(EhcacheXAResource resource);

    /**
     * Setter to the properties properties. This will be called right after the class has been instantiated.
     *
     * @param properties the properties parsed from the config file's
     *                   transactionManagerLookup tag's properties attribute
     */
    void setProperties(Properties properties);
}

==> ehcache-core-2.0.1-sources.jar: net/sf/ehcache/transaction/manager/TransactionManagerLookup.java <==
/**
 *  Copyright 2003-2009 Terracotta, Inc.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package net.sf.ehcache.transaction.manager;

import javax.transaction.TransactionManager;

import net.sf.ehcache.transaction.xa.EhcacheXAResource;

import java.util.Properties;

/**
 * Interface to enable a XA transactional cache to access the JTA TransactionManager.
 * The implementing class can be configured in your xml file. It will then be instanciated by the Cache, during
 * {@link net.sf.ehcache.Cache#initialise() initialization}. It'll then have the properties injected, should any have been specified. And finally,
 * the TransactionManager will be queried for using #getTransactionManager.
 *
 * @author Alex Snaps
 */
public interface TransactionManagerLookup {

    /**
     * Lookup available txnManagers
     * @return TransactionManager
     */
    TransactionManager getTransactionManager();

    /**
     * execute txnManager specific code to register the XAResource for recovery.
     * @param resource the XAResource to register for recovery in the choosen TM.
     */
    void register(EhcacheXAResource resource);

    /**
     * execute txnManager specific code to unregister the XAResource for recovery.
     * @param resource the XAResource to register for recovery in the choosen TM.
     */
    void unregister(EhcacheXAResource resource);

    /**
     * Setter to the properties properties. This will be called right after the class has been instantiated.
     *
     * @param properties the properties parsed from the config file's
     *                   transactionManagerLookup tag's properties attribute
     */
    void setProperties(Properties properties);
}
